Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorBastien Montagne <montagne29@wanadoo.fr>2016-07-12 10:15:49 +0300
committerBastien Montagne <montagne29@wanadoo.fr>2016-07-12 10:15:49 +0300
commit99bb1accbbb8e1ba38f30b073b22deb107bf3220 (patch)
tree7852ec686524e785486c452ec959713abbbef666 /source/blender/makesdna/DNA_sdna_types.h
parent732cd96737007b1411a161369f842209a4c26419 (diff)
parentb8f217ef213f908a6b5407f162a8f980091e838d (diff)
Merge branch 'master' into asset-experiments
Conflicts: source/blender/blenloader/intern/readfile.c source/blender/windowmanager/intern/wm_init_exit.c
Diffstat (limited to 'source/blender/makesdna/DNA_sdna_types.h')
-rw-r--r--source/blender/makesdna/DNA_sdna_types.h10
1 files changed, 3 insertions, 7 deletions
diff --git a/source/blender/makesdna/DNA_sdna_types.h b/source/blender/makesdna/DNA_sdna_types.h
index cb7a371c7c5..26ea5cd4e93 100644
--- a/source/blender/makesdna/DNA_sdna_types.h
+++ b/source/blender/makesdna/DNA_sdna_types.h
@@ -35,11 +35,12 @@
#
#
typedef struct SDNA {
- char *data; /* full copy of 'encoded' data */
+ const char *data; /* full copy of 'encoded' data (when data_alloc is set, otherwise borrowed). */
int datalen; /* length of data */
+ bool data_alloc;
int nr_names; /* total number of struct members */
- const char **names; /* struct member names */
+ const char **names; /* struct member names */
int pointerlen; /* size of a pointer in bytes */
@@ -56,11 +57,6 @@ typedef struct SDNA {
struct GHash *structs_map; /* ghash for faster lookups,
* requires WITH_DNA_GHASH to be used for now */
-
- /* wrong place for this really, its a simple
- * cache for findstruct_nr.
- */
- int lastfind;
} SDNA;
#